Writes an interval object to a CSV file.
write.interval(x, ..., class = FALSE)
Arguments
- x
An interval object to be saved.
- ...
Additional arguments passed to write.csv().
- class
Logical indicating whether to add the class column in the CSV.
Value
No return value, it saves the interval to the given CSV file.